Module kind

Module kind 

Database kind types for identifying different database instances.

This module provides typed identifiers for the different kinds of databases used in Holochain. Each kind implements DatabaseIdentifier to provide a unique string identifier for the database file.

Structs

Authored
Specifies the database used for authoring data by a specific cell.
Conductor
Specifies the database used by the Conductor.
Dht
Specifies the database used for DHT data for a specific DNA.
PeerMetaStore
Database for storing peer metadata.
Wasm
Specifies the database used to save Wasm code.